from distutils.core import setup
setup(
    name = 'nester-ziwei',
    version = '1.1.0',
    py_modules = ['nester-ziwei'],
    author = 'Ziwei',
    author_email = 'zhuang13@stevens.edu',
    url = 'http://www.google.com',
    description = 'Test',
    )
